@@ -232,7 +232,6 @@ sub extend {
   my $logProfile = $coldb->{logProfile};
 
   ##-- sanity check(s)
-   ##-- sanity check(s)
   if (!$opts{slice2keys}) {
      $reldb->logwarn($coldb->{error}="extend(): no 'slice2keys' parameter specified!");
      return undef;
@@ -263,6 +262,11 @@ sub extend {
   $reldb->vlog($logProfile, "extend(): stringify");
   $mp->stringify($groupby->{g2s});
 
+  ##-- trim stringified result profiles (remove unknown elements)
+  foreach my $prf (@{$mp->{profiles}}) {
+    $prf->trim(keep=>$opts{slice2keys}{$prf->{label}});
+  }
+
   return $mp;
 }
 
